@@ -1,9 +1,9 @@
 import click
 
 from sph.check import check
-from sph.editable import create_editable_from_workspace
 from sph.workflow import workflow_group
 from sph.cleanup import cleanup
+from sph.tui import tui
 
 @click.group()
 def be_helpful():
@@ -12,3 +12,4 @@ def be_helpful():
 be_helpful.add_command(cleanup)
 be_helpful.add_command(workflow_group)
 be_helpful.add_command(check)
+be_helpful.add_command(tui)
